Function spawn_base64::base64_encode
source · pub fn base64_encode(data: &[u8]) -> StringExpand description
Base64 encoding function for Ethereum smart contracts Encodes input bytes into a Base64 string.
pub fn base64_encode(data: &[u8]) -> StringBase64 encoding function for Ethereum smart contracts Encodes input bytes into a Base64 string.