Crate spawn_base64
source ·Functions
- Base64 decoding function for Ethereum smart contracts Decodes a Base64 string back into bytes. Now with proper error handling.
- URL-safe Base64 decoding function Decodes a URL-safe Base64 string back into bytes. Now with proper error handling.
- Base64 encoding function for Ethereum smart contracts Encodes input bytes into a Base64 string.
- URL-safe Base64 encoding function Encodes input bytes into a URL-safe Base64 string.